@@ -24,6 +24,7 @@
  *  drawing module for pygame
  */
 #include "pygame.h"
+#include "pygamedocs.h"
 #include <math.h>
 
 /* Many C libraries seem to lack the trunc call (added in C99) */
@@ -47,20 +48,6 @@ static void draw_fillellipse(SDL_Surface *dst, int x, int y, int rx, int ry, Uin
 static void draw_fillpoly(SDL_Surface *dst, int *vx, int *vy, int n, Uint32 color);
 
 
-    /*DOC*/ static char doc_aaline[] =
-    /*DOC*/    "pygame.draw.aaline(Surface, color, startpos, endpos, blend=1) -> Rect\n"
-    /*DOC*/    "draw a line on a surface\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "Draws an anti-aliased line on a surface. This will respect the\n"
-    /*DOC*/    "clipping rectangle. A bounding box of the effected area is returned\n"
-    /*DOC*/    "returned as a rectangle.  The if blend is true, the shades will be\n"
-    /*DOC*/    "be blended with existing pixel shades instead of overwriting them.\n"
-    /*DOC*/    "This function accepts floating point values for the end points.\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "The color argument must be a RGB sequence.\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "This function will temporarily lock the surface.\n"
-    /*DOC*/ ;
 
 static PyObject* aaline(PyObject* self, PyObject* arg)
 {
@@ -82,7 +69,7 @@ static PyObject* aaline(PyObject* self, PyObject* arg)
 	if(surf->format->BytesPerPixel !=3 && surf->format->BytesPerPixel != 4)
 		return RAISE(PyExc_ValueError, "unsupported bit depth for aaline draw (supports 32 & 24 bit)");
 
-	if(RGBAFromObj(colorobj, rgba))
+	if(RGBAFromColorObj(colorobj, rgba))
 		color = SDL_MapRGBA(surf->format, rgba[0], rgba[1], rgba[2], rgba[3]);
 	else
 		return RAISE(PyExc_TypeError, "invalid color argument");
@@ -126,18 +113,6 @@ static PyObject* aaline(PyObject* self, PyObject* arg)
 	return PyRect_New4(left, top, right-left+2, bottom-top+2);
 }
 
-    /*DOC*/ static char doc_line[] =
-    /*DOC*/    "pygame.draw.line(Surface, color, startpos, endpos, width=1) -> Rect\n"
-    /*DOC*/    "draw a line on a surface\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "Draws a line on a surface. This will respect the clipping\n"
-    /*DOC*/    "rectangle. A bounding box of the effected area is returned\n"
-    /*DOC*/    "as a rectangle.\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "The color argument can be either a RGB sequence or mapped color integer.\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "This function will temporarily lock the surface.\n"
-    /*DOC*/ ;
 
 static PyObject* line(PyObject* self, PyObject* arg)
 {
@@ -161,7 +136,7 @@ static PyObject* line(PyObject* self, PyObject* arg)
 
 	if(PyInt_Check(colorobj))
 		color = (Uint32)PyInt_AsLong(colorobj);
-	else if(RGBAFromObj(colorobj, rgba))
+	else if(RGBAFromColorObj(colorobj, rgba))
 		color = SDL_MapRGBA(surf->format, rgba[0], rgba[1], rgba[2], rgba[3]);
 	else
 		return RAISE(PyExc_TypeError, "invalid color argument");
@@ -211,25 +186,6 @@ static PyObject* line(PyObject* self, PyObject* arg)
 }
 
 
-    /*DOC*/ static char doc_aalines[] =
-    /*DOC*/    "pygame.draw.aalines(Surface, color, closed, point_array, blend=1) -> Rect\n"
-    /*DOC*/    "draw multiple connected anti-aliased lines on a surface\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "Draws a sequence on a surface. You must pass at least two points\n"
-    /*DOC*/    "in the sequence of points. The closed argument is a simple boolean\n"
-    /*DOC*/    "and if true, a line will be draw between the first and last points.\n"
-    /*DOC*/    "The boolean blend argument set to true will blend the shades with\n"
-    /*DOC*/    "existing shades instead of overwriting them.\n"
-    /*DOC*/    "This function accepts floating point values for the end points.\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "This will respect the clipping rectangle. A bounding box of the\n"
-    /*DOC*/    "effected area is returned as a rectangle.\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "The color argument must be an RGB sequence.\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "This function will temporarily lock the surface.\n"
-    /*DOC*/ ;
-
 static PyObject* aalines(PyObject* self, PyObject* arg)
 {
 	PyObject *surfobj, *colorobj, *closedobj, *points, *item;
@@ -252,7 +208,7 @@ static PyObject* aalines(PyObject* self, PyObject* arg)
 	if(surf->format->BytesPerPixel !=3 && surf->format->BytesPerPixel != 4)
 		return RAISE(PyExc_ValueError, "unsupported bit depth for aaline draw (supports 32 & 24 bit)");
 
-	if(RGBAFromObj(colorobj, rgba))
+	if(RGBAFromColorObj(colorobj, rgba))
 		color = SDL_MapRGBA(surf->format, rgba[0], rgba[1], rgba[2], rgba[3]);
 	else
 		return RAISE(PyExc_TypeError, "invalid color argument");
@@ -291,10 +247,10 @@ static PyObject* aalines(PyObject* self, PyObject* arg)
 		starty = pts[3] = y;
 		if(clip_and_draw_aaline(surf, &surf->clip_rect, color, pts, blend))
 		{
-			left = min((int)min(pts[0], pts[2]), left);
-			top = min((int)min(pts[1], pts[3]), top);
-			right = max((int)max(pts[0], pts[2]), right);
-			bottom = max((int)max(pts[1], pts[3]), bottom);
+			left = MIN((int)MIN(pts[0], pts[2]), left);
+			top = MIN((int)MIN(pts[1], pts[3]), top);
+			right = MAX((int)MAX(pts[0], pts[2]), right);
+			bottom = MAX((int)MAX(pts[1], pts[3]), bottom);
 		}
 	}
 	if(closed && drawn > 2)
@@ -318,24 +274,6 @@ static PyObject* aalines(PyObject* self, PyObject* arg)
 	return PyRect_New4(left, top, right-left+2, bottom-top+2);
 }
 
-    /*DOC*/ static char doc_lines[] =
-    /*DOC*/    "pygame.draw.lines(Surface, color, closed, point_array, width=1) -> Rect\n"
-    /*DOC*/    "draw multiple connected lines on a surface\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "Draws a sequence on a surface. You must pass at least two points\n"
-    /*DOC*/    "in the sequence of points. The closed argument is a simple boolean\n"
-    /*DOC*/    "and if true, a line will be draw between the first and last points.\n"
-    /*DOC*/    "Note that specifying a linewidth wider than 1 does not fill in the\n"
-    /*DOC*/    "gaps between the lines. Therefore wide lines and sharp corners won't\n"
-    /*DOC*/    "be joined seamlessly.\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "This will respect the clipping rectangle. A bounding box of the\n"
-    /*DOC*/    "effected area is returned as a rectangle.\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "The color argument can be either a RGB sequence or mapped color integer.\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "This function will temporarily lock the surface.\n"
-    /*DOC*/ ;
 
 static PyObject* lines(PyObject* self, PyObject* arg)
 {
@@ -360,7 +298,7 @@ static PyObject* lines(PyObject* self, PyObject* arg)
 
 	if(PyInt_Check(colorobj))
 		color = (Uint32)PyInt_AsLong(colorobj);
-	else if(RGBAFromObj(colorobj, rgba))
+	else if(RGBAFromColorObj(colorobj, rgba))
 		color = SDL_MapRGBA(surf->format, rgba[0], rgba[1], rgba[2], rgba[3]);
 	else
 		return RAISE(PyExc_TypeError, "invalid color argument");
@@ -400,10 +338,10 @@ static PyObject* lines(PyObject* self, PyObject* arg)
 		starty = pts[3] = y;
 		if(clip_and_draw_line_width(surf, &surf->clip_rect, color, width, pts))
 		{
-			left = min(min(pts[0], pts[2]), left);
-			top = min(min(pts[1], pts[3]), top);
-			right = max(max(pts[0], pts[2]), right);
-			bottom = max(max(pts[1], pts[3]), bottom);
+			left = MIN(MIN(pts[0], pts[2]), left);
+			top = MIN(MIN(pts[1], pts[3]), top);
+			right = MAX(MAX(pts[0], pts[2]), right);
+			bottom = MAX(MAX(pts[1], pts[3]), bottom);
 		}
 	}
 	if(closed && drawn > 2)
@@ -429,20 +367,6 @@ static PyObject* lines(PyObject* self, PyObject* arg)
 }
 
 
-    /*DOC*/ static char doc_arc[] =
-    /*DOC*/    "pygame.draw.arc(Surface, color, Rect, angle_start, angle_stop, width=0) -> Rect\n"
-    /*DOC*/    "draw an elliptic arc on a surface\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "Draws an elliptical arc on the Surface. The given rectangle\n"
-    /*DOC*/    "is the area that the circle will fill. The two angle arguments\n"
-    /*DOC*/    "are the initial and final angle (radians, with the zero on the right).\n"
-    /*DOC*/    "The width argument is the thickness to draw the outer edge.\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "The color argument can be either a RGB sequence or mapped color integer.\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "This function will temporarily lock the surface.\n"
-    /*DOC*/ ;
-
 static PyObject* arc(PyObject* self, PyObject* arg)
 {
 	PyObject *surfobj, *colorobj, *rectobj;
@@ -467,7 +391,7 @@ static PyObject* arc(PyObject* self, PyObject* arg)
 
 	if(PyInt_Check(colorobj))
 		color = (Uint32)PyInt_AsLong(colorobj);
-	else if(RGBAFromObj(colorobj, rgba))
+	else if(RGBAFromColorObj(colorobj, rgba))
 		color = SDL_MapRGBA(surf->format, rgba[0], rgba[1], rgba[2], rgba[3]);
 	else
 		return RAISE(PyExc_TypeError, "invalid color argument");
@@ -481,7 +405,7 @@ static PyObject* arc(PyObject* self, PyObject* arg)
 
 	if(!PySurface_Lock(surfobj)) return NULL;
 
-	width = min(width, min(rect->w, rect->h) / 2);
+	width = MIN(width, MIN(rect->w, rect->h) / 2);
 	for(loop=0; loop<width; ++loop)
 	{
 		draw_arc(surf, rect->x+rect->w/2, rect->y+rect->h/2,
@@ -491,29 +415,14 @@ static PyObject* arc(PyObject* self, PyObject* arg)
 
 	if(!PySurface_Unlock(surfobj)) return NULL;
 
-	l = max(rect->x, surf->clip_rect.x);
-	t = max(rect->y, surf->clip_rect.y);
-	r = min(rect->x + rect->w, surf->clip_rect.x + surf->clip_rect.w);
-	b = min(rect->y + rect->h, surf->clip_rect.y + surf->clip_rect.h);
-	return PyRect_New4(l, t, max(r-l, 0), max(b-t, 0));
+	l = MAX(rect->x, surf->clip_rect.x);
+	t = MAX(rect->y, surf->clip_rect.y);
+	r = MIN(rect->x + rect->w, surf->clip_rect.x + surf->clip_rect.w);
+	b = MIN(rect->y + rect->h, surf->clip_rect.y + surf->clip_rect.h);
+	return PyRect_New4(l, t, MAX(r-l, 0), MAX(b-t, 0));
 }
 
 
-
-    /*DOC*/ static char doc_ellipse[] =
-    /*DOC*/    "pygame.draw.ellipse(Surface, color, Rect, width=0) -> Rect\n"
-    /*DOC*/    "draw an ellipse on a surface\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "Draws an elliptical shape on the Surface. The given rectangle\n"
-    /*DOC*/    "is the area that the circle will fill. The width argument is\n"
-    /*DOC*/    "the thickness to draw the outer edge. If width is zero then\n"
-    /*DOC*/    "the ellipse will be filled.\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "The color argument can be either a RGB sequence or mapped color integer.\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "This function will temporarily lock the surface.\n"
-    /*DOC*/ ;
-
 static PyObject* ellipse(PyObject* self, PyObject* arg)
 {
 	PyObject *surfobj, *colorobj, *rectobj;
@@ -536,7 +445,7 @@ static PyObject* ellipse(PyObject* self, PyObject* arg)
 
 	if(PyInt_Check(colorobj))
 		color = (Uint32)PyInt_AsLong(colorobj);
-	else if(RGBAFromObj(colorobj, rgba))
+	else if(RGBAFromColorObj(colorobj, rgba))
 		color = SDL_MapRGBA(surf->format, rgba[0], rgba[1], rgba[2], rgba[3]);
 	else
 		return RAISE(PyExc_TypeError, "invalid color argument");
@@ -553,7 +462,7 @@ static PyObject* ellipse(PyObject* self, PyObject* arg)
 					(Sint16)(rect->w/2), (Sint16)(rect->h/2), color);
 	else
 	{
-		width = min(width, min(rect->w, rect->h) / 2);
+		width = MIN(width, MIN(rect->w, rect->h) / 2);
 		for(loop=0; loop<width; ++loop)
 		{
 			draw_ellipse(surf, rect->x+rect->w/2, rect->y+rect->h/2,
@@ -563,29 +472,14 @@ static PyObject* ellipse(PyObject* self, PyObject* arg)
 
 	if(!PySurface_Unlock(surfobj)) return NULL;
 
-	l = max(rect->x, surf->clip_rect.x);
-	t = max(rect->y, surf->clip_rect.y);
-	r = min(rect->x + rect->w, surf->clip_rect.x + surf->clip_rect.w);
-	b = min(rect->y + rect->h, surf->clip_rect.y + surf->clip_rect.h);
-	return PyRect_New4(l, t, max(r-l, 0), max(b-t, 0));
+	l = MAX(rect->x, surf->clip_rect.x);
+	t = MAX(rect->y, surf->clip_rect.y);
+	r = MIN(rect->x + rect->w, surf->clip_rect.x + surf->clip_rect.w);
+	b = MIN(rect->y + rect->h, surf->clip_rect.y + surf->clip_rect.h);
+	return PyRect_New4(l, t, MAX(r-l, 0), MAX(b-t, 0));
 }
 
 
-
-    /*DOC*/ static char doc_circle[] =
-    /*DOC*/    "pygame.draw.circle(Surface, color, pos, radius, width=0) -> Rect\n"
-    /*DOC*/    "draw a circle on a surface\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "Draws a circular shape on the Surface. The given position\n"
-    /*DOC*/    "is the center of the circle, and radius is the size. The width\n"
-    /*DOC*/    "argument is the thickness to draw the outer edge. If width is\n"
-    /*DOC*/    "zero then the circle will be filled.\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "The color argument can be either a RGB sequence or mapped color integer.\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "This function will temporarily lock the surface.\n"
-    /*DOC*/ ;
-
 static PyObject* circle(PyObject* self, PyObject* arg)
 {
 	PyObject *surfobj, *colorobj;
@@ -605,7 +499,7 @@ static PyObject* circle(PyObject* self, PyObject* arg)
 
 	if(PyInt_Check(colorobj))
 		color = (Uint32)PyInt_AsLong(colorobj);
-	else if(RGBAFromObj(colorobj, rgba))
+	else if(RGBAFromColorObj(colorobj, rgba))
 		color = SDL_MapRGBA(surf->format, rgba[0], rgba[1], rgba[2], rgba[3]);
 	else
 		return RAISE(PyExc_TypeError, "invalid color argument");
@@ -628,30 +522,14 @@ static PyObject* circle(PyObject* self, PyObject* arg)
 
 	if(!PySurface_Unlock(surfobj)) return NULL;
 
-	l = max(posx - radius, surf->clip_rect.x);
-	t = max(posy - radius, surf->clip_rect.y);
-	r = min(posx + radius, surf->clip_rect.x + surf->clip_rect.w);
-	b = min(posy + radius, surf->clip_rect.y + surf->clip_rect.h);
-	return PyRect_New4(l, t, max(r-l, 0), max(b-t, 0));
+	l = MAX(posx - radius, surf->clip_rect.x);
+	t = MAX(posy - radius, surf->clip_rect.y);
+	r = MIN(posx + radius, surf->clip_rect.x + surf->clip_rect.w);
+	b = MIN(posy + radius, surf->clip_rect.y + surf->clip_rect.h);
+	return PyRect_New4(l, t, MAX(r-l, 0), MAX(b-t, 0));
 }
 
 
-
-
-    /*DOC*/ static char doc_polygon[] =
-    /*DOC*/    "pygame.draw.polygon(Surface, color, pointslist, width=0) -> Rect\n"
-    /*DOC*/    "draws a polygon on a surface\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "Draws a polygonal shape on the Surface. The given pointlist\n"
-    /*DOC*/    "is the vertices of the polygon. The width argument is\n"
-    /*DOC*/    "the thickness to draw the outer edge. If width is zero then\n"
-    /*DOC*/    "the polygon will be filled.\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "The color argument can be either a RGB sequence or mapped color integer.\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "This function will temporarily lock the surface.\n"
-    /*DOC*/ ;
-
 static PyObject* polygon(PyObject* self, PyObject* arg)
 {
 	PyObject *surfobj, *colorobj, *points, *item;
@@ -685,7 +563,7 @@ static PyObject* polygon(PyObject* self, PyObject* arg)
 
 	if(PyInt_Check(colorobj))
 		color = (Uint32)PyInt_AsLong(colorobj);
-	else if(RGBAFromObj(colorobj, rgba))
+	else if(RGBAFromColorObj(colorobj, rgba))
 		color = SDL_MapRGBA(surf->format, rgba[0], rgba[1], rgba[2], rgba[3]);
 	else
 		return RAISE(PyExc_TypeError, "invalid color argument");
@@ -717,10 +595,10 @@ static PyObject* polygon(PyObject* self, PyObject* arg)
 		xlist[numpoints] = x;
 		ylist[numpoints] = y;
 		++numpoints;
-		left = min(x, left);
-		top = min(y, top);
-		right = max(x, right);
-		bottom = max(y, bottom);
+		left = MIN(x, left);
+		top = MIN(y, top);
+		right = MAX(x, right);
+		bottom = MAX(y, bottom);
 	}
 
 	if(!PySurface_Lock(surfobj))
@@ -735,32 +613,14 @@ static PyObject* polygon(PyObject* self, PyObject* arg)
 	if(!PySurface_Unlock(surfobj))
 		return NULL;
 
-	left = max(left, surf->clip_rect.x);
-	top = max(top, surf->clip_rect.y);
-	right = min(right, surf->clip_rect.x + surf->clip_rect.w);
-	bottom = min(bottom, surf->clip_rect.y + surf->clip_rect.h);
+	left = MAX(left, surf->clip_rect.x);
+	top = MAX(top, surf->clip_rect.y);
+	right = MIN(right, surf->clip_rect.x + surf->clip_rect.w);
+	bottom = MIN(bottom, surf->clip_rect.y + surf->clip_rect.h);
 	return PyRect_New4(left, top, right-left+1, bottom-top+1);
 }
 
 
-    /*DOC*/ static char doc_rect[] =
-    /*DOC*/    "pygame.draw.rect(Surface, color, Rect, width=0) -> Rect\n"
-    /*DOC*/    "draws a rectangle on a surface\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "Draws a rectangular shape on the Surface. The given Rect\n"
-    /*DOC*/    "is the area of the rectangle. The width argument is\n"
-    /*DOC*/    "the thickness to draw the outer edge. If width is zero then\n"
-    /*DOC*/    "the rectangle will be filled.\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "The color argument can be either a RGB sequence or mapped color integer.\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "This function will temporarily lock the surface.\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "Keep in mind the Surface.fill() method works just as well\n"
-    /*DOC*/    "for drawing filled rectangles. In fact the Surface.fill()\n"
-    /*DOC*/    "can be hardware accelerated when the moons are in alignement.\n"
-    /*DOC*/ ;
-
 static PyObject* rect(PyObject* self, PyObject* arg)
 {
 	PyObject *surfobj, *colorobj, *rectobj, *points, *args, *ret=NULL;
@@ -848,10 +708,10 @@ static int clip_and_draw_line_width(SDL_Surface* surf, SDL_Rect* rect, Uint32 co
 		if(clip_and_draw_line(surf, rect, color, newpts))
 		{
 			anydrawn = 1;
-			range[0] = min(newpts[0], range[0]);
-			range[1] = min(newpts[1], range[1]);
-			range[2] = max(newpts[2], range[2]);
-			range[3] = max(newpts[3], range[3]);
+			range[0] = MIN(newpts[0], range[0]);
+			range[1] = MIN(newpts[1], range[1]);
+			range[2] = MAX(newpts[2], range[2]);
+			range[3] = MAX(newpts[3], range[3]);
 		}
 		if(loop+1<width)
 		{
@@ -862,10 +722,10 @@ static int clip_and_draw_line_width(SDL_Surface* surf, SDL_Rect* rect, Uint32 co
 			if(clip_and_draw_line(surf, rect, color, newpts))
 			{
 				anydrawn = 1;
-				range[0] = min(newpts[0], range[0]);
-				range[1] = min(newpts[1], range[1]);
-				range[2] = max(newpts[2], range[2]);
-				range[3] = max(newpts[3], range[3]);
+				range[0] = MIN(newpts[0], range[0]);
+				range[1] = MIN(newpts[1], range[1]);
+				range[2] = MAX(newpts[2], range[2]);
+				range[3] = MAX(newpts[3], range[3]);
 			}
 		}
 	}
@@ -1050,9 +910,15 @@ static int set_at(SDL_Surface* surf, int x, int y, Uint32 color)
 		default:/*case 3:*/
 			SDL_GetRGB(color, format, rgb, rgb+1, rgb+2);
 			byte_buf = (Uint8*)(pixels + y * surf->pitch) + x * 3;
-			*(byte_buf + (format->Rshift >> 3)) = rgb[0];
-			*(byte_buf + (format->Gshift >> 3)) = rgb[1];
-			*(byte_buf + (format->Bshift >> 3)) = rgb[2];
+#if (SDL_BYTEORDER == SDL_LIL_ENDIAN)
+                        *(byte_buf + (format->Rshift >> 3)) = rgb[0];
+                        *(byte_buf + (format->Gshift >> 3)) = rgb[1];
+                        *(byte_buf + (format->Bshift >> 3)) = rgb[2];
+#else
+                        *(byte_buf + 2 - (format->Rshift >> 3)) = rgb[0];
+                        *(byte_buf + 2 - (format->Gshift >> 3)) = rgb[1];
+                        *(byte_buf + 2 - (format->Bshift >> 3)) = rgb[2];
+#endif
 			break;
 	}
 	return 1;
@@ -1096,6 +962,15 @@ static void drawaaline(SDL_Surface* surf, Uint32 color, float x1, float y1, floa
 
 	xd = x2-x1;
 	yd = y2-y1;
+
+        if (xd == 0 && yd == 0)
+        {
+            /* Single point. Due to the nature of the aaline clipping, this
+             * is less exact than the normal line. */
+            set_at (surf, x1, y1, color);
+            return;
+        }
+
 	if(fabs(xd)>fabs(yd)) {
 		if(x1>x2) {
 			swaptmp=x1; x1=x2; x2=swaptmp;
@@ -1299,8 +1174,8 @@ static void drawhorzlineclip(SDL_Surface* surf, Uint32 color, int x1, int y1, in
                 x1 = x2; x2 = temp;
 	}
 
-	x1 = max(x1, surf->clip_rect.x);
-	x2 = min(x2, surf->clip_rect.x + surf->clip_rect.w-1);
+	x1 = MAX(x1, surf->clip_rect.x);
+	x2 = MIN(x2, surf->clip_rect.x + surf->clip_rect.w-1);
 
         if(x2 < surf->clip_rect.x || x1 >= surf->clip_rect.x + surf->clip_rect.w)
                 return;
@@ -1370,8 +1245,8 @@ static void drawvertlineclip(SDL_Surface* surf, Uint32 color, int x1, int y1, in
 		int temp = y1;
 		y1 = y2; y2 = temp;
 	}
-	y1 = max(y1, surf->clip_rect.y);
-	y2 = min(y2, surf->clip_rect.y + surf->clip_rect.h-1);
+	y1 = MAX(y1, surf->clip_rect.y);
+	y2 = MIN(y2, surf->clip_rect.y + surf->clip_rect.h-1);
 	if(y2 - y1 < 1)
 		set_at( surf, x1, y1, color);
 	else
@@ -1631,8 +1506,8 @@ static void draw_fillpoly(SDL_Surface *dst, int *vx, int *vy, int n, Uint32 colo
 	maxy = vy[0];
 	for (i=1; (i < n); i++)
 	{
-		miny = min(miny, vy[i]);
-		maxy = max(maxy, vy[i]);
+		miny = MIN(miny, vy[i]);
+		maxy = MAX(maxy, vy[i]);
 	}
 
 	/* Draw, scanning y */
@@ -1676,49 +1551,34 @@ static void draw_fillpoly(SDL_Surface *dst, int *vx, int *vy, int n, Uint32 colo
 
 
 
-
-
-
-
 static PyMethodDef draw_builtins[] =
 {
-	{ "aaline", aaline, 1, doc_aaline },
-	{ "line", line, 1, doc_line },
-	{ "aalines", aalines, 1, doc_aalines },
-	{ "lines", lines, 1, doc_lines },
-	{ "ellipse", ellipse, 1, doc_ellipse },
-	{ "arc", arc, 1, doc_arc },
-	{ "circle", circle, 1, doc_circle },
-	{ "polygon", polygon, 1, doc_polygon },
-	{ "rect", rect, 1, doc_rect },
+	{ "aaline", aaline, METH_VARARGS, DOC_PYGAMEDRAWAALINE },
+	{ "line", line, METH_VARARGS, DOC_PYGAMEDRAWLINE },
+	{ "aalines", aalines, METH_VARARGS, DOC_PYGAMEDRAWAALINES },
+	{ "lines", lines, METH_VARARGS, DOC_PYGAMEDRAWLINES },
+	{ "ellipse", ellipse, METH_VARARGS, DOC_PYGAMEDRAWELLIPSE },
+	{ "arc", arc, METH_VARARGS, DOC_PYGAMEDRAWARC },
+	{ "circle", circle, METH_VARARGS, DOC_PYGAMEDRAWCIRCLE },
+	{ "polygon", polygon, METH_VARARGS, DOC_PYGAMEDRAWPOLYGON },
+	{ "rect", rect, METH_VARARGS, DOC_PYGAMEDRAWRECT },
 
-	{ NULL, NULL }
+	{ NULL, NULL, 0, NULL }
 };
 
 
-
-    /*DOC*/ static char doc_pygame_draw_MODULE[] =
-    /*DOC*/    "Contains routines to draw onto a surface.\n"
-    /*DOC*/    "\n"
-    /*DOC*/    "Note that all\n"
-    /*DOC*/    "drawing routines use direct pixel access, so the surfaces\n"
-    /*DOC*/    "must be locked for use. The draw functions will temporarily\n"
-    /*DOC*/    "lock the surface if needed, but if performing many drawing\n"
-    /*DOC*/    "routines together, it would be best to surround the drawing\n"
-    /*DOC*/    "code with a lock/unlock pair.\n"
-    /*DOC*/ ;
-
 PYGAME_EXPORT
 void initdraw(void)
 {
 	PyObject *module, *dict;
 
     /* create the module */
-	module = Py_InitModule3("draw", draw_builtins, doc_pygame_draw_MODULE);
+	module = Py_InitModule3("draw", draw_builtins, DOC_PYGAMEDRAW);
 	dict = PyModule_GetDict(module);
 
 	/*imported needed apis*/
 	import_pygame_base();
+        import_pygame_color();
 	import_pygame_rect();
 	import_pygame_surface();
 }
